@@ -50,6 +50,7 @@ __all__ = (
     "MigrationTypeValueType",
     "NestingLevelValueType",
     "ParquetVersionValueType",
+    "PluginNameValueType",
     "RefreshSchemasStatusTypeValueType",
     "ReleaseStatusValuesType",
     "ReloadOptionValueType",
@@ -102,6 +103,7 @@ MessageFormatValueType = Literal["json", "json-unformatted"]
 MigrationTypeValueType = Literal["cdc", "full-load", "full-load-and-cdc"]
 NestingLevelValueType = Literal["none", "one"]
 ParquetVersionValueType = Literal["parquet-1-0", "parquet-2-0"]
+PluginNameValueType = Literal["no-preference", "pglogical", "test-decoding"]
 RefreshSchemasStatusTypeValueType = Literal["failed", "refreshing", "successful"]
 ReleaseStatusValuesType = Literal["beta"]
 ReloadOptionValueType = Literal["data-reload", "validate-only"]
