@@ -34,6 +34,7 @@ from .literals import (
     MigrationTypeValueType,
     NestingLevelValueType,
     ParquetVersionValueType,
+    PluginNameValueType,
     RefreshSchemasStatusTypeValueType,
     ReloadOptionValueType,
     ReplicationEndpointTypeValueType,
@@ -1158,6 +1159,7 @@ EndpointSettingTypeDef = TypedDict(
         "Applicability": str,
         "IntValueMin": int,
         "IntValueMax": int,
+        "DefaultValue": str,
     },
     total=False,
 )
@@ -1315,6 +1317,7 @@ KafkaSettingsTypeDef = TypedDict(
         "SslCaCertificateArn": str,
         "SaslUsername": str,
         "SaslPassword": str,
+        "NoHexPrefix": bool,
     },
     total=False,
 )
@@ -1331,6 +1334,7 @@ KinesisSettingsTypeDef = TypedDict(
         "IncludeTableAlterOperations": bool,
         "IncludeControlDetails": bool,
         "IncludeNullAndEmpty": bool,
+        "NoHexPrefix": bool,
     },
     total=False,
 )
@@ -1409,6 +1413,7 @@ _OptionalModifyEndpointMessageRequestTypeDef = TypedDict(
         "MicrosoftSQLServerSettings": "MicrosoftSQLServerSettingsTypeDef",
         "IBMDb2Settings": "IBMDb2SettingsTypeDef",
         "DocDbSettings": "DocDbSettingsTypeDef",
+        "ExactSettings": bool,
     },
     total=False,
 )
@@ -1683,7 +1688,11 @@ OracleSettingsTypeDef = TypedDict(
         "SecurityDbEncryptionName": str,
         "ServerName": str,
         "SpatialDataOptionToGeoJsonFunctionName": str,
+        "StandbyDelayTime": int,
         "Username": str,
+        "UseBFile": bool,
+        "UseDirectPathFullLoad": bool,
+        "UseLogminerReader": bool,
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
         "SecretsManagerOracleAsmAccessRoleArn": str,
@@ -1741,11 +1750,15 @@ PostgreSQLSettingsTypeDef = TypedDict(
         "DdlArtifactsSchema": str,
         "ExecuteTimeout": int,
         "FailTasksOnLobTruncation": bool,
+        "HeartbeatEnable": bool,
+        "HeartbeatSchema": str,
+        "HeartbeatFrequency": int,
         "Password": str,
         "Port": int,
         "ServerName": str,
         "Username": str,
         "SlotName": str,
+        "PluginName": PluginNameValueType,
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
     },
